@@ -3,8 +3,11 @@ import json
 from ctapipe.core import Provenance
 from ctapipe.core.provenance import _ActivityProvenance
 
+import pytest
 
-def test_Provenance():
+
+@pytest.fixture
+def provenance():
     prov = Provenance()
     prov.start_activity("test1")
     prov.add_input_file("input.txt")
@@ -14,11 +17,10 @@ def test_Provenance():
     prov.add_input_file("input_b.txt")
     prov.finish_activity("test2")
     prov.finish_activity("test1")
+    return prov
 
     assert set(prov.finished_activity_names) == {"test2", "test1"}
 
-    return prov
-
 
 def test_ActivityProvenance():
     prov = _ActivityProvenance()
@@ -41,11 +43,12 @@ def test_provenence_contextmanager():
     assert "myactivity" not in prov.active_activity_names
 
 
-if __name__ == "__main__":
+def test_provenance_json(provenance: Provenance):
+    data = json.loads(provenance.as_json())
 
-    import logging
+    activity = data[0]
 
-    logging.basicConfig(level=logging.DEBUG)
-
-    prov = test_Provenance()
-    print(json.dumps(prov.provenance, indent=4))
+    assert "python" in activity["system"]
+    packages = activity["system"]["python"].get("packages")
+    assert isinstance(packages, list)
+    assert any(p["name"] == "numpy" for p in packages)
