@@ -5,17 +5,33 @@ import textwrap
 from abc import abstractmethod
 import pathlib
 import os
+import re
 
-from traitlets import default
+from traitlets import default, TraitError
 from traitlets.config import Application, Configurable
 
 from .. import __version__ as version
-from .traits import Path, Enum, Bool, flag, Dict
+from .traits import Path, Enum, Bool, Dict
 from . import Provenance
 from .component import Component
 from .logging import create_logging_config, ColoredFormatter, DEFAULT_LOGGING
 
 
+__all__ = ["Tool", "ToolConfigurationError"]
+
+
+class CollectTraitWarningsHandler(logging.NullHandler):
+    regex = re.compile(".*Config option.*not recognized")
+
+    def __init__(self):
+        super().__init__()
+        self.errors = []
+
+    def handle(self, record):
+        if self.regex.match(record.msg) and record.levelno == logging.WARNING:
+            self.errors.append(record.msg)
+
+
 class ToolConfigurationError(Exception):
     def __init__(self, message):
         # Call the base class constructor with the parameters it needs
@@ -33,14 +49,14 @@ class Tool(Application):
 
     Tool developers should create sub-classes, and a name,
     description, usage examples should be added by defining the
-    `name`, `description` and `examples` class attributes as
-    strings. The `aliases` attribute can be set to cause a lower-level
-    `Component` parameter to become a high-level command-line
+    ``name``, ``description`` and ``examples`` class attributes as
+    strings. The ``aliases`` attribute can be set to cause a lower-level
+    `~ctapipe.core.Component` parameter to become a high-level command-line
     parameter (See example below). The `setup()`, `start()`, and
     `finish()` methods should be defined in the sub-class.
 
     Additionally, any `ctapipe.core.Component` used within the `Tool`
-    should have their class in a list in the `classes` attribute,
+    should have their class in a list in the ``classes`` attribute,
     which will automatically add their configuration parameters to the
     tool.
 
@@ -97,9 +113,9 @@ class Tool(Application):
            main()
 
 
-    If this `main()` method is registered in `setup.py` under
+    If this ``main()`` function is registered in ``setup.py`` under
     *entry_points*, it will become a command-line tool (see examples
-    in the `ctapipe/tools` subdirectory).
+    in the ``ctapipe/tools`` subdirectory).
 
     """
 
@@ -138,19 +154,21 @@ class Tool(Application):
         aliases = {
             "config": "Tool.config_file",
             "log-level": "Tool.log_level",
-            "log-file": "Tool.log_file",
-            "log": "Tool.log_file",
-            "l": "Tool.log_file",
+            ("l", "log-file"): "Tool.log_file",
             "log-file-level": "Tool.log_file_level",
         }
         self.aliases.update(aliases)
-        self.flags.update(flag("q", "Tool.quiet", "Disable console logging."))
+        flags = {
+            ("q", "quiet"): ({"Tool": {"quiet": True}}, "Disable console logging.")
+        }
+        self.flags.update(flags)
 
         self.is_setup = False
         self.version = version
         self.raise_config_file_errors = True  # override traitlets.Application default
 
         self.log = logging.getLogger("ctapipe." + self.name)
+        self.trait_warning_handler = CollectTraitWarningsHandler()
         self.update_logging_config()
 
     def initialize(self, argv=None):
@@ -183,6 +201,9 @@ class Tool(Application):
 
         logging.config.dictConfig(cfg)
 
+        # re-add our custom handler every time the config is updated.
+        self.log.addHandler(self.trait_warning_handler)
+
     def add_component(self, component_instance):
         """
         constructs and adds a component to the list of registered components,
@@ -215,7 +236,7 @@ class Tool(Application):
     @abstractmethod
     def setup(self):
         """set up the tool (override in subclass). Here the user should
-        construct all `Components` and open files, etc."""
+        construct all ``Components`` and open files, etc."""
         pass
 
     @abstractmethod
@@ -256,6 +277,14 @@ class Tool(Application):
             self.is_setup = True
             self.log.debug(f"CONFIG: {self.get_current_config()}")
             Provenance().add_config(self.get_current_config())
+
+            # check for any traitlets warnings using our custom handler
+            if len(self.trait_warning_handler.errors) > 0:
+                raise ToolConfigurationError(f"Found config errors")
+
+            # remove handler to not impact performance with regex matching
+            self.log.removeHandler(self.trait_warning_handler)
+
             self.start()
             self.finish()
             self.log.info(f"Finished: {self.name}")
