@@ -1,6 +1,7 @@
 import numpy as np
 import astropy.units as u
 
+from ..instrument import CameraGeometry
 from ..containers import ConcentrationContainer
 from .hillas import camera_to_shower_coordinates
 from ..utils.quantities import all_to_value
@@ -8,7 +9,7 @@ from ..utils.quantities import all_to_value
 __all__ = ["concentration_parameters"]
 
 
-def concentration_parameters(geom, image, hillas_parameters):
+def concentration_parameters(geom: CameraGeometry, image, hillas_parameters):
     """
     Calculate concentraion values.
 
@@ -21,16 +22,16 @@ def concentration_parameters(geom, image, hillas_parameters):
     h = hillas_parameters
     unit = h.x.unit
 
-    pix_x, pix_y, x, y, length, width = all_to_value(
-        geom.pix_x, geom.pix_y, h.x, h.y, h.length, h.width, unit=unit
+    pix_x, pix_y, x, y, length, width, pixel_width = all_to_value(
+        geom.pix_x, geom.pix_y, h.x, h.y, h.length, h.width, geom.pixel_width, unit=unit
     )
 
     delta_x = pix_x - x
     delta_y = pix_y - y
 
-    # sort pixels by distance to cog
-    cog_pixels = np.argsort(delta_x ** 2 + delta_y ** 2)
-    conc_cog = np.sum(image[cog_pixels[:3]]) / h.intensity
+    # take pixels within one pixel diameter from the cog
+    mask_cog = (delta_x ** 2 + delta_y ** 2) < pixel_width ** 2
+    conc_cog = np.sum(image[mask_cog]) / h.intensity
 
     if hillas_parameters.width.value != 0:
         # get all pixels inside the hillas ellipse
