@@ -1,6 +1,7 @@
 """
 High level image processing  (ImageProcessor Component)
 """
+import numpy as np
 
 
 from ..containers import (
@@ -25,6 +26,15 @@ from . import (
 
 
 DEFAULT_IMAGE_PARAMETERS = ImageParametersContainer()
+DEFAULT_TRUE_IMAGE_PARAMETERS = ImageParametersContainer()
+DEFAULT_TRUE_IMAGE_PARAMETERS.intensity_statistics = IntensityStatisticsContainer(
+    max=np.int32(-1),
+    min=np.int32(-1),
+    mean=np.float64(np.nan),
+    std=np.float64(np.nan),
+    skewness=np.float64(np.nan),
+    kurtosis=np.float64(np.nan),
+)
 DEFAULT_TIMING_PARAMETERS = TimingParametersContainer()
 DEFAULT_PEAKTIME_STATISTICS = PeakTimeStatisticsContainer()
 
@@ -88,7 +98,12 @@ class ImageProcessor(TelescopeComponent):
         self._process_telescope_event(event)
 
     def _parameterize_image(
-        self, tel_id, image, signal_pixels, peak_time=None
+        self,
+        tel_id,
+        image,
+        signal_pixels,
+        peak_time=None,
+        default=DEFAULT_IMAGE_PARAMETERS,
     ) -> ImageParametersContainer:
         """Apply image cleaning and calculate image features
 
@@ -163,7 +178,7 @@ class ImageProcessor(TelescopeComponent):
 
         # return the default container (containing nan values) for no
         # parameterization
-        return DEFAULT_IMAGE_PARAMETERS
+        return default
 
     def _process_telescope_event(self, event):
         """
@@ -198,6 +213,7 @@ class ImageProcessor(TelescopeComponent):
                     image=sim_camera.true_image,
                     signal_pixels=sim_camera.true_image > 0,
                     peak_time=None,  # true image from simulation has no peak time
+                    default=DEFAULT_TRUE_IMAGE_PARAMETERS,
                 )
                 self.log.debug(
                     "sim params: %s",
