@@ -4,12 +4,13 @@ from ctapipe.image.toymodel import obtain_time_image, WaveformModel
 from pytest import approx
 from scipy.stats import poisson, skewnorm, norm
 import astropy.units as u
+import pytest
 
 
-def test_intensity():
+@pytest.mark.parametrize("seed", [None, 0])
+def test_intensity(seed):
     from ctapipe.image.toymodel import Gaussian
 
-    np.random.seed(0)
     geom = CameraGeometry.from_name("LSTCam")
 
     x, y = u.Quantity([0.2, 0.3], u.m)
@@ -21,7 +22,13 @@ def test_intensity():
     # make a toymodel shower model
     model = Gaussian(x=x, y=y, width=width, length=length, psi=psi)
 
-    _, signal, _ = model.generate_image(geom, intensity=intensity, nsb_level_pe=5)
+    if seed is None:
+        _, signal, _ = model.generate_image(geom, intensity=intensity, nsb_level_pe=5)
+    else:
+        rng = np.random.default_rng(seed)
+        _, signal, _ = model.generate_image(
+            geom, intensity=intensity, nsb_level_pe=5, rng=rng
+        )
 
     # test if signal reproduces given cog values
     assert np.average(geom.pix_x.to_value(u.m), weights=signal) == approx(0.2, rel=0.15)
@@ -43,7 +50,7 @@ def test_skewed():
 
     # test if the parameters we calculated for the skew normal
     # distribution produce the correct moments
-    np.random.seed(0)
+    rng = np.random.default_rng(0)
     geom = CameraGeometry.from_name("LSTCam")
 
     x, y = u.Quantity([0.2, 0.3], u.m)
@@ -56,7 +63,7 @@ def test_skewed():
     model = SkewedGaussian(
         x=x, y=y, width=width, length=length, psi=psi, skewness=skewness
     )
-    model.generate_image(geom, intensity=intensity, nsb_level_pe=5)
+    model.generate_image(geom, intensity=intensity, nsb_level_pe=5, rng=rng)
 
     a, loc, scale = model._moments_to_parameters()
     mean, var, skew = skewnorm(a=a, loc=loc, scale=scale).stats(moments="mvs")
