@@ -11,8 +11,8 @@ __all__ = ["CameraDescription"]
 
 class CameraDescription:
     """
-    Describes a Cherenkov camera and it's associated `CameraGeometry` and
-    `CameraReadout`
+    Describes a Cherenkov camera and its associated
+    `~ctapipe.instrument.CameraGeometry` and `~ctapipe.instrument.CameraReadout`
 
     Parameters
     ----------
@@ -40,9 +40,9 @@ class CameraDescription:
     @classmethod
     def get_known_camera_names(cls):
         """
-        Returns a list of camera names that are registered in
-        `ctapipe_resources`. These are all the camera names that can be
-        instantiated by the `from_name` method
+        Returns a list of camera names that are available currently on the system.
+        Beware that the `from_name` method also tries to download camera descriptions
+        from the data server, so this list might not be exhaustive.
 
         Returns
         -------
@@ -69,7 +69,10 @@ class CameraDescription:
         """
 
         geometry = CameraGeometry.from_name(camera_name)
-        readout = CameraReadout.from_name(camera_name)
+        try:
+            readout = CameraReadout.from_name(camera_name)
+        except FileNotFoundError:
+            readout = None
         return cls(camera_name=camera_name, geometry=geometry, readout=readout)
 
     def __str__(self):
