@@ -3,11 +3,10 @@ from astropy.utils.decorators import lazyproperty
 import logging
 import numpy as np
 import tables
-from ctapipe.instrument import SubarrayDescription
-from ctapipe.io.eventsource import EventSource
-from ctapipe.io import HDF5TableReader
-from ctapipe.io.datalevels import DataLevel
-from ctapipe.containers import (
+
+from ..core import Container, Field
+from ..instrument import SubarrayDescription
+from ..containers import (
     ConcentrationContainer,
     ArrayEventContainer,
     DL1CameraContainer,
@@ -24,7 +23,13 @@ from ctapipe.containers import (
     TriggerContainer,
     ImageParametersContainer,
 )
-from ctapipe.utils import IndexFinder
+from .eventsource import EventSource
+from .hdf5tableio import HDF5TableReader
+from .datalevels import DataLevel
+from ..utils import IndexFinder
+
+
+__all__ = ["DL1EventSource"]
 
 
 logger = logging.getLogger(__name__)
@@ -91,7 +96,14 @@ class DL1EventSource(EventSource):
         super().__init__(input_url=input_url, config=config, parent=parent, **kwargs)
 
         self.file_ = tables.open_file(self.input_url)
-        self._subarray_info = SubarrayDescription.from_hdf(self.input_url)
+        self._full_subarray_info = SubarrayDescription.from_hdf(self.input_url)
+
+        if self.allowed_tels:
+            self._subarray_info = self._full_subarray_info.select_subarray(
+                self.allowed_tels
+            )
+        else:
+            self._subarray_info = self._full_subarray_info
         self._simulation_configs = self._parse_simulation_configs()
         self.datamodel_version = self.file_.root._v_attrs[
             "CTA PRODUCT DATA MODEL VERSION"
@@ -115,20 +127,27 @@ class DL1EventSource(EventSource):
     def is_compatible(file_path):
         with open(file_path, "rb") as f:
             magic_number = f.read(8)
+
         if magic_number != b"\x89HDF\r\n\x1a\n":
             return False
+
         with tables.open_file(file_path) as f:
             metadata = f.root._v_attrs
             if "CTA PRODUCT DATA LEVEL" not in metadata._v_attrnames:
                 return False
+
             if metadata["CTA PRODUCT DATA LEVEL"] != "DL1":
                 return False
+
             if "CTA PRODUCT DATA MODEL VERSION" not in metadata._v_attrnames:
                 return False
-            if (
-                metadata["CTA PRODUCT DATA MODEL VERSION"]
-                not in COMPATIBLE_DL1_VERSIONS
-            ):
+
+            version = metadata["CTA PRODUCT DATA MODEL VERSION"]
+            if version not in COMPATIBLE_DL1_VERSIONS:
+                logger.error(
+                    f"File is DL1 file but has unsupported version {version}"
+                    f", supported versions are {COMPATIBLE_DL1_VERSIONS}"
+                )
                 return False
         return True
 
@@ -189,11 +208,15 @@ class DL1EventSource(EventSource):
         # the correct mcheader assigned by matching the obs_id
         # Alternatively this becomes a flat list
         # and the obs_id matching part needs to be done in _generate_events()
+        class ObsIdContainer(Container):
+            container_prefix = ""
+            obs_id = Field(-1)
+
         simulation_configs = {}
         if "simulation" in self.file_.root.configuration:
             reader = HDF5TableReader(self.file_).read(
                 "/configuration/simulation/run",
-                containers=[SimulationConfigContainer(), EventIndexContainer()],
+                containers=[SimulationConfigContainer(), ObsIdContainer()],
             )
             for (config, index) in reader:
                 simulation_configs[index.obs_id] = config
@@ -297,9 +320,13 @@ class DL1EventSource(EventSource):
             data.count = counter
             data.trigger = trigger
             data.index = index
-            data.trigger.tels_with_trigger = self.subarray.tel_mask_to_tel_ids(
+            data.trigger.tels_with_trigger = self._full_subarray_info.tel_mask_to_tel_ids(
                 data.trigger.tels_with_trigger
             )
+            if self.allowed_tels:
+                data.trigger.tels_with_trigger = np.intersect1d(
+                    data.trigger.tels_with_trigger, np.array(list(self.allowed_tels))
+                )
 
             # Maybe there is a simpler way  to do this
             # Beware: tels_with_trigger contains all triggered telescopes whereas
@@ -336,8 +363,7 @@ class DL1EventSource(EventSource):
                         )
                         continue
 
-                    dl1 = next(image_readers[key])
-                    data.dl1.tel[tel] = dl1
+                    data.dl1.tel[tel] = next(image_readers[key])
 
                     if self.has_simulated_dl1:
                         if key not in simulated_image_iterators:
@@ -363,7 +389,7 @@ class DL1EventSource(EventSource):
                     # Best would probbaly be if we could directly read
                     # into the ImageParametersContainer
                     params = next(param_readers[f"tel_{tel:03d}"])
-                    dl1.parameters = ImageParametersContainer(
+                    data.dl1.tel[tel].parameters = ImageParametersContainer(
                         hillas=params[0],
                         timing=params[1],
                         leakage=params[2],
