@@ -38,7 +38,7 @@ DL1_DATA_MODEL_CHANGE_HISTORY = """
 PROV = Provenance()
 
 
-def write_reference_metadata_headers(obs_id, subarray, writer):
+def write_reference_metadata_headers(obs_ids, subarray, writer, is_simulation):
     """
     Attaches Core Provenence headers to an output HDF5 file.
     Right now this is hard-coded for use with the ctapipe-stage1-process tool
@@ -68,7 +68,11 @@ def write_reference_metadata_headers(obs_id, subarray, writer):
             data_model_url="",
             format="hdf5",
         ),
-        process=meta.Process(type_="Simulation", subtype="", id_=int(obs_id)),
+        process=meta.Process(
+            type_="Simulation" if is_simulation else "Observation",
+            subtype="",
+            id_=int(min(obs_ids)),  # FIXME: hack, proper id needs to be defined
+        ),
         activity=meta.Activity.from_provenance(activity),
         instrument=meta.Instrument(
             site="Other",  # need a way to detect site...
@@ -109,9 +113,9 @@ class DL1Writer(Component):
         help="Store DL1/Event/Image data in output", default_value=False
     ).tag(config=True)
 
-    write_parameters = Bool(
-        help="Compute and store image parameters", default_value=True
-    ).tag(config=True)
+    write_parameters = Bool(help="Store image parameters", default_value=True).tag(
+        config=True
+    )
 
     compression_level = Int(
         help="compression level, 0=None, 9=maximum", default_value=5, min=0, max=9
@@ -173,20 +177,26 @@ class DL1Writer(Component):
         # here we just set up data, but all real initializtion should be in
         # setup(), which is called when the first event is read.
 
+        self.event_source = event_source
+        self._at_least_one_event = False
         self._is_simulation = event_source.is_simulation
         self._subarray: SubarrayDescription = event_source.subarray
 
-        if self._is_simulation:
-            self._simulation_config = event_source.simulation_config
-        else:
-            self._simulation_config = None
-
-        self._obs_id = event_source.obs_ids[0]
         self._hdf5_filters = None
         self._last_pointing_tel: DefaultDict[Tuple] = None
         self._last_pointing: Tuple = None
         self._writer: TableWriter = None
 
+        self._setup_output_path()
+        self._subarray.to_hdf(self.output_path)  # must be first (uses astropy io)
+        self._setup_compression()
+        self._setup_writer()
+        if self._is_simulation:
+            self._write_simulation_configuration()
+
+        # store last pointing to only write unique poitings
+        self._last_pointing_tel = defaultdict(lambda: (np.nan * u.deg, np.nan * u.deg))
+
     def __enter__(self):
         return self
 
@@ -195,15 +205,11 @@ class DL1Writer(Component):
 
     def __call__(self, event: ArrayEventContainer):
         """
-        Write a single event to the output file. On the first event, the output
-        file is set up
+        Write a single event to the output file.
         """
+        self._at_least_one_event = True
 
-        # perform delayed initialization on first event
-        if self._writer is None:
-            self.setup()
-
-        # Write subarray evvent data
+        # Write subarray event data
         self._write_subarray_pointing(event, writer=self._writer)
 
         self.log.debug(f"WRITING EVENT {event.index}")
@@ -220,28 +226,19 @@ class DL1Writer(Component):
         # write telescope event data
         self._write_telescope_events(self._writer, event)
 
-    def setup(self):
-        """called on first event"""
-        self.log.debug("Setting Up DL1 Output")
-
-        self._setup_output_path()
-        self._subarray.to_hdf(self.output_path)  # must be first (uses astropy io)
-        self._setup_compression()
-        self._setup_writer()
-        if self._is_simulation:
-            self._write_simulation_configuration()
-
-        # store last pointing to only write unique poitings
-        self._last_pointing_tel = defaultdict(lambda: (np.nan * u.deg, np.nan * u.deg))
-
     def finish(self):
         """ called after all events are done """
         self.log.info("Finishing DL1 output")
+        if not self._at_least_one_event:
+            self.log.warning("No events have been written to the output file")
         if self._writer:
             if self.write_index_tables:
                 self._generate_indices()
             write_reference_metadata_headers(
-                subarray=self._subarray, obs_id=self._obs_id, writer=self._writer
+                subarray=self._subarray,
+                obs_ids=self.event_source.obs_ids,
+                writer=self._writer,
+                is_simulation=self._is_simulation,
             )
             self._writer.close()
             self._writer = None
@@ -396,19 +393,25 @@ class DL1Writer(Component):
             container_prefix = ""
             obs_id = Field(0, "Simulation Run Identifier")
 
-        extramc = ExtraSimInfo()
-        extramc.obs_id = self._obs_id
-        self._simulation_config.prefix = ""
-        self._writer.write(
-            "configuration/simulation/run", [extramc, self._simulation_config]
-        )
+        if len(self.event_source.obs_ids) > 1:
+            for obs_id, config in self.event_source.simulation_config.items():
+                extramc = ExtraSimInfo(obs_id=obs_id)
+                config.prefix = ""
+
+                self._writer.write("configuration/simulation/run", [extramc, config])
+        else:
+            extramc = ExtraSimInfo(obs_id=self.event_source.obs_ids[0])
+            config = self.event_source.simulation_config
+            config.prefix = ""
+
+            self._writer.write("configuration/simulation/run", [extramc, config])
 
     def write_simulation_histograms(self, event_source):
         """Write the distribution of thrown showers
 
         TODO: this needs to be fixed, since it currently requires access to the
         low-level _file attribute of the SimTelEventSource.  Instead, SimTelEventSource should
-        provide this as header info, like `source.simulation_config`
+        provide this as header info, like ``source.simulation_config``
 
         Notes
         -----
@@ -420,7 +423,6 @@ class DL1Writer(Component):
           histograms will be found.
 
         """
-
         if not self._is_simulation:
             self.log.debug("Not writing simulation histograms for observed data")
             return
@@ -462,7 +464,7 @@ class DL1Writer(Component):
             hist_container.prefix = ""
             for hist in hists:
                 if hist["id"] == 6:
-                    fill_from_simtel(self._obs_id, hist, hist_container)
+                    fill_from_simtel(self.event_source.obs_ids[0], hist, hist_container)
                     self._writer.write(
                         table_name="simulation/service/shower_distribution",
                         containers=hist_container,
