@@ -20,11 +20,11 @@ class EventSource(Component):
     """
     Parent class for EventSources.
 
-    EventSources read input files and generate `ArrayEvents`
-    when iterated over.
+    EventSources read input files and generate `~ctapipe.containers.ArrayEventContainer`
+    instances when iterated over.
 
     A new EventSource should be created for each type of event file read
-    into ctapipe, e.g. sim_telarray files are read by the `SimTelEventSource`.
+    into ctapipe, e.g. sim_telarray files are read by the `~ctapipe.io.SimTelEventSource`.
 
     EventSource provides a common high-level interface for accessing event
     information from different data sources (simulation or different camera
@@ -74,7 +74,7 @@ class EventSource(Component):
         Path to the input event file.
     max_events : int
         Maximum number of events to loop through in generator
-    allowed_tels: Set[int] or None
+    allowed_tels: Set or None
         Ids of the telescopes to be included in the data.
         If given, only this subset of telescopes will be present in the
         generated events. If None, all available telescopes are used.
