@@ -7,6 +7,7 @@ import sys
 
 from .utils import get_parser
 from ..core import Provenance, get_module_version
+from ..core.plugins import detect_and_import_io_plugins
 from ..utils import datasets
 
 from pkg_resources import resource_filename
@@ -31,7 +32,7 @@ _dependencies = sorted(
 )
 
 _optional_dependencies = sorted(
-    ["ctapipe_resources", "pytest", "graphviz", "targetio", "matplotlib"]
+    ["ctapipe_resources", "pytest", "graphviz", "matplotlib"]
 )
 
 
@@ -55,6 +56,7 @@ def main(args=None):
     parser.add_argument(
         "--all", dest="show_all", action="store_true", help="show all info"
     )
+    parser.add_argument("--plugins", action="store_true", help="Print plugin info")
     args = parser.parse_args(args)
 
     if len(sys.argv) <= 1:
@@ -70,6 +72,7 @@ def info(
     dependencies=False,
     resources=False,
     system=False,
+    plugins=False,
     show_all=False,
 ):
     """Print various info to the console.
@@ -93,6 +96,9 @@ def info(
     if system or show_all:
         _info_system()
 
+    if plugins or show_all:
+        _info_plugins()
+
 
 def _info_version():
     """Print version info."""
@@ -139,14 +145,7 @@ def _info_dependencies():
     print("\n*** ctapipe optional dependencies ***\n")
 
     for name in _optional_dependencies:
-        try:
-            module = importlib.import_module(name)
-            version = module.__version__
-        except ImportError:
-            version = "not installed"
-        except AttributeError:
-            version = "installed, but __version__ doesn't exist"
-
+        version = get_module_version(name)
         print(f"{name:>20s} -- {version}")
 
 
@@ -199,5 +198,18 @@ def _info_system():
             print("{:>20.20s} -- {:<60.60s}".format(name, str(val)))
 
 
+def _info_plugins():
+    plugins = detect_and_import_io_plugins()
+    print("\n*** ctapipe io plugins ***\n")
+
+    if not plugins:
+        print("No io plugins installed")
+        return
+
+    for name in plugins:
+        version = get_module_version(name)
+        print(f"{name:>20s} -- {version}")
+
+
 if __name__ == "__main__":
     main()
