@@ -20,15 +20,15 @@ class ArrayDisplay:
     telescopes in the subarray, colored by telescope type, however you can
     also color the telescopes by a value (like trigger pattern, or some other
     scalar per-telescope parameter). To set the color value, simply set the
-    `value` attribute, and the fill color will be updated with the value. You
+    ``value`` attribute, and the fill color will be updated with the value. You
     might want to set the border color to zero to avoid confusion between the
     telescope type color and the value color (
-    `array_disp.telescope.set_linewidth(0)`)
+    ``array_disp.telescope.set_linewidth(0)``)
 
     To display a vector field over the telescope positions, e.g. for
-    reconstruction, call `set_uv()` to set cartesian vectors, or `set_r_phi()`
-    to set polar coordinate vectors.  These both take an array of length
-    N_tels, or a single value.
+    reconstruction, call `set_vector_uv()` to set cartesian vectors,
+    or `set_vector_rho_phi()` to set polar coordinate vectors.
+    These both take an array of length N_tels, or a single value.
 
 
     Parameters
@@ -223,7 +223,7 @@ class ArrayDisplay:
         time_gradient: Dict[int, value of time gradient (no units)]
             dictionary for value of the time gradient for each telescope
         angle_offset: Float
-            This should be the `event.pointing.array_azimuth` parameter
+            This should be the ``event.pointing.array_azimuth`` parameter
 
         """
 
